==> fantacalciobazar_0.5.tar.gz: fantacalciobazar/crea_sondaggio.php <==
<?php

##################################################################################
#    FANTACALCIOBAZAR
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################


include("./controlla_pass.php");
include("$percorso_cartella_dati/head.php");
if ($pass_admin_errata == "NO") {


if (!@is_file("$percorso_cartella_dati/sondaggio.php")) {
if ($crea_sondaggio) {
if (!$domanda) $crea = "NO";
$domanda = stripslashes($domanda);
$domanda = str_replace("$","\\\$",$domanda);
$domanda = str_replace("\"","\\\"",$domanda);
if (!$tipo) $crea = "NO";
ereg_replace("[0-9]","",$num_voti_segreti);
if ((ereg_replace("[0-9]","",$num_voti_segreti) != "" or $num_voti_segreti == "" or $num_voti_segreti == 0) and $tipo == "votazione_segreta") $crea = "NO";
if ((ereg_replace("[0-9]","",$num_voti_palesi) != "" or $num_voti_palesi == "" or $num_voti_palesi == 0) and $tipo == "votazione_palese") $crea = "NO";
if ($crea != "NO") {
if ($tipo == "votazione_segreta" or $tipo == "sondaggio_segreto")  $voto_palese = "NO";
else $voto_palese = "SI";
if ($tipo == "votazione_segreta") $voti_consentiti =$num_voti_segreti ;
if ($tipo == "votazione_palese") $voti_consentiti =$num_voti_palesi ;
if ($tipo == "sondaggio_segreto" or $tipo == "sondaggio_palese") $voti_consentiti = 0;
$file_sondaggio = fopen("$percorso_cartella_dati/sondaggio.php","w+");
flock($file_sondaggio,2);
$testo_file = "<?php
\$voti_consentiti = $voti_consentiti;
\$voto_palese = $voto_palese;
\$domanda = \"$domanda\";
\$opzioni = array();
";
$num_giocatori=count($pass);
reset($pass);
for($num1 = 0 ; $num1 < $num_giocatori; $num1++) {
$giocatore = key($pass);
$testo_file .= "\$voti_$giocatore = array();
";
next($pass);
} # fine for $num1
$testo_file .= "?>";
fwrite($file_sondaggio,$testo_file);
flock($file_sondaggio,3);
fclose($file_sondaggio);
echo "Sondaggio creato.<br>";
} # fine if ($crea != "NO")
else echo "ERRORE.<br>";
echo "<form method=\"post\" action=\"./crea_sondaggio.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"submit\" name=\"vai\" value=\"OK\">
</form>";
} # fine if ($crea_sondaggio)
else {
echo "<form method=\"post\" action=\"./crea_sondaggio.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
Domanda: <input type=\"text\" name=\"domanda\" size=\"50\"><br>
<br>Tipo:<br>
<input type=\"radio\" name=\"tipo\" value=\"votazione_segreta\"> Votazione segreta con 
 <input type=\"text\" name=\"num_voti_segreti\" size=\"2\" maxlength=\"2\" value=\"1\"> voto/i per giocatore<br>
<input type=\"radio\" name=\"tipo\" value=\"votazione_palese\"> Votazione palese con 
 <input type=\"text\" name=\"num_voti_palesi\" size=\"2\" maxlength=\"2\" value=\"1\"> voto/i per giocatore<br>
<input type=\"radio\" name=\"tipo\" value=\"sondaggio_segreto\" checked> Sondaggio segreto (infiniti voti, non si registrano i votanti)<br>
<input type=\"radio\" name=\"tipo\" value=\"sondaggio_palese\">Sondaggio palese (infiniti voti, tutti vedono i voti degli altri)<br>
<center><input type=\"submit\" name=\"crea_sondaggio\" value=\"Crea il sondaggio\"></center>
</form>";
echo "<center><form method=\"post\" action=\"mercato.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"submit\" name=\"torna\" value=\"Torna indietro\">
</form></center>";
} # fine else if ($crea_sondaggio)
} # fine if (!@is_file("$percorso_cartella_dati/sondaggio.php"))


else {

if ($cancella_sondaggio) {
if (unlink("$percorso_cartella_dati/sondaggio.php")) echo "Sondaggio cancellato";
else echo "ERRORE.<br>";
echo "<form method=\"post\" action=\"./crea_sondaggio.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"submit\" name=\"vai\" value=\"OK\">
</form>";
} # fine if ($cancella_sondaggio)
else {

if ($nuova_opzione) {
$lock = fopen("$percorso_cartella_dati/sondaggio.lock","w+");
flock($lock,2);
include("$percorso_cartella_dati/sondaggio.php");
$linee_sondaggio = file("$percorso_cartella_dati/sondaggio.php");
$filesondaggio = fopen("$percorso_cartella_dati/sondaggio.php","w+");
flock($filesondaggio,2);
$num_linee_sondaggio = count($linee_sondaggio);
for ($num1 = 0 ; $num1 < $num_linee_sondaggio; $num1++) {
if (substr($linee_sondaggio[$num1],0,10) == "\$opzioni =") {
if (count($opzioni) != 0) $linee_sondaggio[$num1] = str_replace(");",",);",$linee_sondaggio[$num1]);
$nuova_opzione = stripslashes($nuova_opzione);
$nuova_opzione = str_replace("$","\\\$",$nuova_opzione);
$nuova_opzione = str_replace("\"","\\\"",$nuova_opzione);
$linee_sondaggio[$num1] = str_replace(");","\"$nuova_opzione\");",$linee_sondaggio[$num1]);
} # fine if (substr($linee_sondaggio[$num1],0,10) == "\$opzioni =")
$linea = substr($linee_sondaggio[$num1],0,2);
if ($linea == "?>") $linee_sondaggio[$num1] = "\$voti".(count($opzioni)+1)." = 0;
?>";
} # fine for $num1
rewind($filesondaggio);
for ($num1 = 0 ; $num1 < $num_linee_sondaggio; $num1++) {
fwrite($filesondaggio,$linee_sondaggio[$num1]);
} # fine for $num1
flock($filesondaggio,3);
fclose($filesondaggio);
flock($lock,3);
fclose($lock);
} # fine if ($nuova_opzione)

include("$percorso_cartella_dati/sondaggio.php");
if ($voti_consentiti == 0) {
echo "<center>Sondaggio ";
$o = "o";
} # fine if ($voti_consentiti == 0)
else {
echo "<center>Votazione ";
$o = "a";
} # fine else if ($voti_consentiti == 0)
if ($voto_palese == "SI") echo "palese";
else echo "segret$o";
if ($voti_consentiti > 1) echo " ($voti_consentiti voti consentiti)";
echo "</center><br>";
echo "<b>Domanda</b>: $domanda<br>
<b>Opzioni</b>:<br>";
$num_opzioni = count($opzioni);
for ($num1 = 0 ; $num1 < $num_opzioni; $num1++) {
echo "- ".$opzioni[$num1]."<br>";
} # fine for $num1
echo "<form method=\"post\" action=\"./crea_sondaggio.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"submit\" name=\"aggiungi_opzione\" value=\"Aggiungi l'opzone\"> :
 <input type=\"text\" name=\"nuova_opzione\" size=\"50\"><br>
</form>";
echo "<center><form method=\"post\" action=\"./crea_sondaggio.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"submit\" name=\"cancella_sondaggio\" value=\"Cancella il sondaggio\">
</form></center>";

echo "<center><form method=\"post\" action=\"mercato.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"submit\" name=\"torna\" value=\"Torna indietro\">
</form></center>";

} # fine else if ($cancella_sondaggio)

} # fine else if (!@is_file("$percorso_cartella_dati/sondaggio.php"))

} # fine if ($pass_admin_errata == "NO")

include("$percorso_cartella_dati/foot.php");
?>

==> fantacalciobazar_0.5.5.tar.gz: fantacalciobazar/crea_sondaggio.php <==
<?php

##################################################################################
#    FANTACALCIOBAZAR
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################


include('./include/funzioni.php');
include("./controlla_pass.php");
include("$percorso_cartella_dati/head.php");
if ($pass_admin_errata == "NO") {


if (!@is_file("$percorso_cartella_dati/sondaggio.php")) {
if ($crea_sondaggio) {
if (!$domanda) $crea = "NO";
$domanda = stripslashes($domanda);
$domanda = str_replace("$","\\\$",$domanda);
$domanda = str_replace("\"","\\\"",$domanda);
if (!$tipo) $crea = "NO";
preg_replace("/[0-9]/","",$num_voti_segreti);
if ((preg_replace("/[0-9]/","",$num_voti_segreti) != "" or $num_voti_segreti == "" or $num_voti_segreti == 0) and $tipo == "votazione_segreta") $crea = "NO";
if ((preg_replace("/[0-9]/","",$num_voti_palesi) != "" or $num_voti_palesi == "" or $num_voti_palesi == 0) and $tipo == "votazione_palese") $crea = "NO";
if ($crea != "NO") {
if ($tipo == "votazione_segreta" or $tipo == "sondaggio_segreto")  $voto_palese = "NO";
else $voto_palese = "SI";
if ($tipo == "votazione_segreta") $voti_consentiti =$num_voti_segreti ;
if ($tipo == "votazione_palese") $voti_consentiti =$num_voti_palesi ;
if ($tipo == "sondaggio_segreto" or $tipo == "sondaggio_palese") $voti_consentiti = 0;
$file_sondaggio = fopen("$percorso_cartella_dati/sondaggio.php","w+");
flock($file_sondaggio,2);
$testo_file = "<?php
\$voti_consentiti = $voti_consentiti;
\$voto_palese = $voto_palese;
\$domanda = \"$domanda\";
\$opzioni = array();
";
$num_giocatori=count($pass);
reset($pass);
for($num1 = 0 ; $num1 < $num_giocatori; $num1++) {
$giocatore = key($pass);
$testo_file .= "\$voti_$giocatore = array();
";
next($pass);
} # fine for $num1
$testo_file .= "?>";
fwrite($file_sondaggio,$testo_file);
flock($file_sondaggio,3);
fclose($file_sondaggio);
echo "Sondaggio creato.<br>";
} # fine if ($crea != "NO")
else echo "ERRORE.<br>";
echo "<form  accept-charset=\"utf-8\" method=\"post\" action=\"./crea_sondaggio.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"submit\" name=\"vai\" value=\"OK\">
</form>";
} # fine if ($crea_sondaggio)
else {
echo "<form  accept-charset=\"utf-8\" method=\"post\" action=\"./crea_sondaggio.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
Domanda: <input type=\"text\" name=\"domanda\" size=\"50\"><br>
<br>Tipo:<br>
<input type=\"radio\" name=\"tipo\" value=\"votazione_segreta\"> Votazione segreta con 
 <input type=\"text\" name=\"num_voti_segreti\" size=\"2\" maxlength=\"2\" value=\"1\"> voto/i per giocatore<br>
<input type=\"radio\" name=\"tipo\" value=\"votazione_palese\"> Votazione palese con 
 <input type=\"text\" name=\"num_voti_palesi\" size=\"2\" maxlength=\"2\" value=\"1\"> voto/i per giocatore<br>
<input type=\"radio\" name=\"tipo\" value=\"sondaggio_segreto\" checked> Sondaggio segreto (infiniti voti, non si registrano i votanti)<br>
<input type=\"radio\" name=\"tipo\" value=\"sondaggio_palese\">Sondaggio palese (infiniti voti, tutti vedono i voti degli altri)<br>
<center><input type=\"submit\" name=\"crea_sondaggio\" value=\"Crea il sondaggio\"></center>
</form>";
echo "<center><form  accept-charset=\"utf-8\" method=\"post\" action=\"mercato.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"submit\" name=\"torna\" value=\"Torna indietro\">
</form></center>";
} # fine else if ($crea_sondaggio)
} # fine if (!@is_file("$percorso_cartella_dati/sondaggio.php"))


else {

if ($cancella_sondaggio) {
if (unlink("$percorso_cartella_dati/sondaggio.php")) echo "Sondaggio cancellato";
else echo "ERRORE.<br>";
echo "<form  accept-charset=\"utf-8\" method=\"post\" action=\"./crea_sondaggio.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"submit\" name=\"vai\" value=\"OK\">
</form>";
} # fine if ($cancella_sondaggio)
else {

if ($nuova_opzione) {
$lock = fopen("$percorso_cartella_dati/sondaggio.lock","w+");
flock($lock,2);
include("$percorso_cartella_dati/sondaggio.php");
$linee_sondaggio = file("$percorso_cartella_dati/sondaggio.php");
$filesondaggio = fopen("$percorso_cartella_dati/sondaggio.php","w+");
flock($filesondaggio,2);
$num_linee_sondaggio = count($linee_sondaggio);
for ($num1 = 0 ; $num1 < $num_linee_sondaggio; $num1++) {
if (substr($linee_sondaggio[$num1],0,10) == "\$opzioni =") {
if (count($opzioni) != 0) $linee_sondaggio[$num1] = str_replace(");",",);",$linee_sondaggio[$num1]);
$nuova_opzione = stripslashes($nuova_opzione);
$nuova_opzione = str_replace("$","\\\$",$nuova_opzione);
$nuova_opzione = str_replace("\"","\\\"",$nuova_opzione);
$linee_sondaggio[$num1] = str_replace(");","\"$nuova_opzione\");",$linee_sondaggio[$num1]);
} # fine if (substr($linee_sondaggio[$num1],0,10) == "\$opzioni =")
$linea = substr($linee_sondaggio[$num1],0,2);
if ($linea == "?>") $linee_sondaggio[$num1] = "\$voti".(count($opzioni)+1)." = 0;
?>";
} # fine for $num1
rewind($filesondaggio);
for ($num1 = 0 ; $num1 < $num_linee_sondaggio; $num1++) {
fwrite($filesondaggio,$linee_sondaggio[$num1]);
} # fine for $num1
flock($filesondaggio,3);
fclose($filesondaggio);
flock($lock,3);
fclose($lock);
} # fine if ($nuova_opzione)

include("$percorso_cartella_dati/sondaggio.php");
if ($voti_consentiti == 0) {
echo "<center>Sondaggio ";
$o = "o";
} # fine if ($voti_consentiti == 0)
else {
echo "<center>Votazione ";
$o = "a";
} # fine else if ($voti_consentiti == 0)
if ($voto_palese == "SI") echo "palese";
else echo "segret$o";
if ($voti_consentiti > 1) echo " ($voti_consentiti voti consentiti)";
echo "</center><br>";
echo "<b>Domanda</b>: $domanda<br>
<b>Opzioni</b>:<br>";
$num_opzioni = count($opzioni);
for ($num1 = 0 ; $num1 < $num_opzioni; $num1++) {
echo "- ".$opzioni[$num1]."<br>";
} # fine for $num1
echo "<form  accept-charset=\"utf-8\" method=\"post\" action=\"./crea_sondaggio.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"submit\" name=\"aggiungi_opzione\" value=\"Aggiungi l'opzone\"> :
 <input type=\"text\" name=\"nuova_opzione\" size=\"50\"><br>
</form>";
echo "<center><form  accept-charset=\"utf-8\" method=\"post\" action=\"./crea_sondaggio.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"submit\" name=\"cancella_sondaggio\" value=\"Cancella il sondaggio\">
</form></center>";

echo "<center><form  accept-charset=\"utf-8\" method=\"post\" action=\"mercato.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"submit\" name=\"torna\" value=\"Torna indietro\">
</form></center>";

} # fine else if ($cancella_sondaggio)

} # fine else if (!@is_file("$percorso_cartella_dati/sondaggio.php"))

} # fine if ($pass_admin_errata == "NO")

include("$percorso_cartella_dati/foot.php");
?>
